@@ -17,7 +17,7 @@ use Scalar::Util;
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw(Compare);
-$VERSION = 1.21;
+$VERSION = 1.2102;
 $DEBUG   = 0;
 
 my %handler;
@@ -347,6 +347,37 @@ structures, the module will spit a warning.  For this to affect you, you need to
 around a hundred levels deep though, and if you do that you have bigger
 problems which I can't help you with ;-)
 
+=head1 STRUCTURAL EQUIVALENCE vs DATA EQUIVALENCE
+
+Consider the following two structures:
+
+    $a={}; $a->{a}=$a;
+    $b={}; $b->{a}=$b;
+
+They have the same structure - a hashref, with a key called 'a' whose value
+is a reference to the original hashref.  However, they contain different
+data, because the values are different.  This is evident when you stringify
+and compare them:
+
+    $a={}; $a->{a}=$a;
+    $b={}; $b->{a}=$b;
+    print $a->{a}."\n";
+    print $b->{a}."\n";
+    print Compare($a, $b)."\n"'
+
+says:
+
+    HASH(0x812c1c8)
+    HASH(0x812cb40)
+    0
+
+If, however, the $b hashref was constructed thus:
+
+    $b={}; $b->{a}=$a;
+
+so that it referred to $a instead of itself, they would be considered the
+same because the data are the same.
+
 =head1 PLUGINS
 
 The module takes plug-ins so you can provide specialised routines for
@@ -389,9 +420,9 @@ the empty list, and then call the register_plugins class method:
 
 or you could call it as a function if that floats your boat.
 
-=head1 CVS
+=head1 CODE REPOSITORY
 
-L<http://drhyde.cvs.sourceforge.net/drhyde/perlmodules/Data-Compare/>
+L<http://www.cantrell.org.uk/cgit/cgit.cgi/perlmodules/>
 
 =head1 BUGS
 
@@ -404,6 +435,11 @@ might happen if you started your process as a priveleged user and then
 dropped priveleges.  This is due to how we check for Taintedness.  If this
 affects you, please supply a portable patch.
 
+Please report any other bugs either by email to David Cantrell (see below
+for address) or using rt.cpan.org:
+
+L<https://rt.cpan.org/Ticket/Create.html?Queue=Data-Compare>
+
 =head1 AUTHOR
 
 Fabien Tassin E<lt>fta@sofaraway.orgE<gt>
@@ -416,12 +452,13 @@ Copyright (c) 1999-2001 Fabien Tassin. All rights reserved.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-Some parts copyright 2003 - 2008 David Cantrell.
+Some parts copyright 2003 - 2009 David Cantrell.
 
 Seeing that Fabien seems to have disappeared, David Cantrell has become
 a co-maintainer so he can apply needed patches.  The licence, of course,
-remains the same, and all communications about this module should be
-CCed to Fabien in case he ever returns and wants his baby back.
+remains the same.  As the "perl licence" is "Artistic or GPL, your choice",
+you can find them as the files ARTISTIC.txt and GPL2.txt in the
+distribution.
 
 =head1 SEE ALSO
 
